<img src="./docs/imgs/LAMPLogo.png" width="300" />

# *L*aser-plasma *A*nalysis for *M*ultiple *P*latforms

LAMP is a python-based API to facilitate and streamline the analysis of laser-plasma experiment data.

## Installation

```
pip install lamp
```

Or to upgrade to the latest version;

```
pip upgrade lamp
```

For a list of required packages please see the [documentation](https://github.com/brendankettle/LAMP/blob/main/docs/UserGuide.md).

## Using the API
For help on getting started and understanding the full capabilities of LAMP, please see the [user guide](https://github.com/brendankettle/LAMP/blob/main/docs/UserGuide.md).

## Reporting bugs
Please report any problems using the [github issue tracker](https://github.com/brendankettle/LAMP/issues).

## Mailing list
To stay up to date with LAMP developments and get notified of releases, please email Brendan requesting subscription to the mailing list.